==> ssp-center-api-1.1.93-20231218.100336-3-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/OperatorMediaReportRspDTO.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @Author yuquanfeng
 * @Date 2022/4/11
 * @Description
 * @Param
 * @return
 **/
@Data
public class OperatorMediaReportRspDTO implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 积木ID
     */
    private String pageId;

    /**
     * 积木url
     */
    private String pageUrl;

    /**
     * 媒体ID
     */
    private Long appId;

    /**
     * 媒体名称
     */
    private String appName;

    /**
     * 平台ID
     */
    private Integer mediaPlatform;

    /**
     * 平台名称
     */
    private String platformName;

    /**
     * 账户ID
     */
    private String accountId;

    /**
     * 策略ID 1-多O概率上报 2-单资源概率上报 3-直接上报 4-固定收益上报 5-固定收益-自定义上报
     */
    private Integer strategyId;

    /**
     * 备注
     */
    private String remark;

    /**
     * 删除标识 0-否 1-是
     */
    private Integer isDeleted;

    /**
     * 扩展字段1
     */
    private String extendValue1;

    /**
     * 创建人ID
     */
    private Long createId;

    /**
     * 固定收益-单位（分）
     */
    private Long income;

    /**
     * 扩展字段2
     */
    private String extendValue2;

    /**
     * 运营商id tb_telecom_operator
     */
    private Long operatorId;

    /**
     * 配置列表
     */
    private List<OperatorMediaReportConfigDto> reportConfigList;

    /**
     * 扩展字段 百度-token
     */
    private String extendValue;
    /**
     * srcId vivo特有
     */
    private String srcId;

    /**
     * 360 key
     */
    private String api360Key;
    /**
     * 360 secret
     */
    private String api360Secret;
    /**
     * 万能wifi钥匙 客户ID
     */
    private String wnClientId;

    /**
     * 万能wifi钥匙 签名密钥
     */
    private String wnSecretkey;

    /**
     * vivo clientId
     */
    private String clientId;
    /**
     * vivo clientSecret
     */
    private String clientSecret;

    /**
     * oppo api_id
     */
    private String apiId;
    /**
     * oppo api_key
     */
    private String apiKey;

    /**
     * sina 转化ID
     */
    private String convId;
    /**
     * sina token
     */
    private String token;

    /**
     * youku appKey
     */
    private String appKey;

    /**
     * 凤凰网转化id
     */
    private String fenghuangConvertId;
    /**
     * 凤凰网加密密钥
     */
    private String fenghuangSecretKey;

}

==> ssp-center-api-1.2.88-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/OperatorMediaReportRspDTO.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @Author yuquanfeng
 * @Date 2022/4/11
 * @Description
 * @Param
 * @return
 **/
@Data
public class OperatorMediaReportRspDTO implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 积木ID
     */
    private String pageId;

    /**
     * 积木url
     */
    private String pageUrl;

    /**
     * 媒体ID
     */
    private Long appId;

    /**
     * 媒体名称
     */
    private String appName;

    /**
     * 平台ID
     */
    private Integer mediaPlatform;

    /**
     * 平台名称
     */
    private String platformName;

    /**
     * 账户ID
     */
    private String accountId;

    /**
     * 策略ID 1-多O概率上报 2-单资源概率上报 3-直接上报 4-固定收益上报 5-固定收益-自定义上报
     */
    private Integer strategyId;

    /**
     * 备注
     */
    private String remark;

    /**
     * 删除标识 0-否 1-是
     */
    private Integer isDeleted;

    /**
     * 扩展字段1
     */
    private String extendValue1;

    /**
     * 创建人ID
     */
    private Long createId;

    /**
     * 固定收益-单位（分）
     */
    private Long income;

    /**
     * 扩展字段2
     */
    private String extendValue2;

    /**
     * 运营商id tb_telecom_operator
     */
    private Long operatorId;

    private String operatorName;

    /**
     * 配置列表
     */
    private List<OperatorMediaReportConfigDto> reportConfigList;

    /**
     * 扩展字段 百度-token
     */
    private String extendValue;
    /**
     * srcId vivo特有
     */
    private String srcId;

    /**
     * 360 key
     */
    private String api360Key;
    /**
     * 360 secret
     */
    private String api360Secret;
    /**
     * 万能wifi钥匙 客户ID
     */
    private String wnClientId;

    /**
     * 万能wifi钥匙 签名密钥
     */
    private String wnSecretkey;

    /**
     * vivo clientId
     */
    private String clientId;
    /**
     * vivo clientSecret
     */
    private String clientSecret;

    /**
     * oppo api_id
     */
    private String apiId;
    /**
     * oppo api_key
     */
    private String apiKey;

    /**
     * sina 转化ID
     */
    private String convId;
    /**
     * sina token
     */
    private String token;

    /**
     * youku appKey
     */
    private String appKey;

    /**
     * 凤凰网转化id
     */
    private String fenghuangConvertId;
    /**
     * 凤凰网加密密钥
     */
    private String fenghuangSecretKey;

    private Long industryId;

    private String industryName;

    private Integer pageType;

    private String advertKey;

}
